==> sal-cluster-admin-api-1.9.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/controller/md/sal/cluster/admin/rev151013/RemoveShardReplicaInputBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013;
import com.google.common.base.MoreObjects;
import com.google.common.collect.ImmutableMap;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link RemoveShardReplicaInputBuilder} instances.
 *
 * @see RemoveShardReplicaInputBuilder
 *
 */
public class RemoveShardReplicaInputBuilder implements Builder<RemoveShardReplicaInput> {

    private DataStoreType _dataStoreType;
    private String _memberName;
    private String _shardName;


    Map<Class<? extends Augmentation<RemoveShardReplicaInput>>, Augmentation<RemoveShardReplicaInput>> augmentation = Collections.emptyMap();

    public RemoveShardReplicaInputBuilder() {
    }

    public RemoveShardReplicaInputBuilder(RemoveShardReplicaInput base) {
        this._dataStoreType = base.getDataStoreType();
        this._memberName = base.getMemberName();
        this._shardName = base.getShardName();
        if (base instanceof RemoveShardReplicaInputImpl) {
            RemoveShardReplicaInputImpl impl = (RemoveShardReplicaInputImpl) base;
            if (!impl.augmentation.isEmpty()) {
                this.augmentation = new HashMap<>(impl.augmentation);
            }
        } else if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<RemoveShardReplicaInput>>, Augmentation<RemoveShardReplicaInput>> aug =((AugmentationHolder<RemoveShardReplicaInput>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
    }


    public DataStoreType getDataStoreType() {
        return _dataStoreType;
    }
    
    public String getMemberName() {
        return _memberName;
    }
    
    public String getShardName() {
        return _shardName;
    }
    
    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<RemoveShardReplicaInput>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public RemoveShardReplicaInputBuilder setDataStoreType(final DataStoreType value) {
        this._dataStoreType = value;
        return this;
    }
    
    public RemoveShardReplicaInputBuilder setMemberName(final String value) {
        this._memberName = value;
        return this;
    }
    
    public RemoveShardReplicaInputBuilder setShardName(final String value) {
        this._shardName = value;
        return this;
    }
    
    public RemoveShardReplicaInputBuilder addAugmentation(Class<? extends Augmentation<RemoveShardReplicaInput>> augmentationType, Augmentation<RemoveShardReplicaInput> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public RemoveShardReplicaInputBuilder removeAugmentation(Class<? extends Augmentation<RemoveShardReplicaInput>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public RemoveShardReplicaInput build() {
        return new RemoveShardReplicaInputImpl(this);
    }

    private static final class RemoveShardReplicaInputImpl implements RemoveShardReplicaInput {
    
        private final DataStoreType _dataStoreType;
        private final String _memberName;
        private final String _shardName;
    
        private Map<Class<? extends Augmentation<RemoveShardReplicaInput>>, Augmentation<RemoveShardReplicaInput>> augmentation = Collections.emptyMap();
    
        RemoveShardReplicaInputImpl(RemoveShardReplicaInputBuilder base) {
            this._dataStoreType = base.getDataStoreType();
            this._memberName = base.getMemberName();
            this._shardName = base.getShardName();
            this.augmentation = ImmutableMap.copyOf(base.augmentation);
        }
    
        @Override
        public Class<RemoveShardReplicaInput> getImplementedInterface() {
            return RemoveShardReplicaInput.class;
        }
    
        @Override
        public DataStoreType getDataStoreType() {
            return _dataStoreType;
        }
        
        @Override
        public String getMemberName() {
            return _memberName;
        }
        
        @Override
        public String getShardName() {
            return _shardName;
        }
        
        @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
        @Override
        public <E$$ extends Augmentation<RemoveShardReplicaInput>> E$$ augmentation(Class<E$$> augmentationType) {
            return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_dataStoreType);
            result = prime * result + Objects.hashCode(_memberName);
            result = prime * result + Objects.hashCode(_shardName);
            result = prime * result + Objects.hashCode(augmentation);
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!RemoveShardReplicaInput.class.equals(((DataObject)obj).getImplementedInterface())) {
                return false;
            }
            RemoveShardReplicaInput other = (RemoveShardReplicaInput)obj;
            if (!Objects.equals(_dataStoreType, other.getDataStoreType())) {
                return false;
            }
            if (!Objects.equals(_memberName, other.getMemberName())) {
                return false;
            }
            if (!Objects.equals(_shardName, other.getShardName())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                RemoveShardReplicaInputImpl otherImpl = (RemoveShardReplicaInputImpl) obj;
                if (!Objects.equals(augmentation, otherImpl.augmentation)) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<RemoveShardReplicaInput>>, Augmentation<RemoveShardReplicaInput>> e : augmentation.entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("RemoveShardReplicaInput");
            CodeHelpers.appendValue(helper, "_dataStoreType", _dataStoreType);
            CodeHelpers.appendValue(helper, "_memberName", _memberName);
            CodeHelpers.appendValue(helper, "_shardName", _shardName);
            CodeHelpers.appendValue(helper, "augmentation", augmentation.values());
            return helper.toString();
        }
    }
}

==> sal-cluster-admin-api-1.10.1-sources.jar: org/opendaylight/yang/gen/v1/urn/opendaylight/params/xml/ns/yang/controller/md/sal/cluster/admin/rev151013/RemoveShardReplicaInputBuilder.java <==
package org.opendaylight.yang.gen.v1.urn.opendaylight.params.xml.ns.yang.controller.md.sal.cluster.admin.rev151013;
import com.google.common.base.MoreObjects;
import java.lang.Class;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.SuppressWarnings;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;
import org.opendaylight.yangtools.concepts.Builder;
import org.opendaylight.yangtools.yang.binding.AbstractAugmentable;
import org.opendaylight.yangtools.yang.binding.Augmentation;
import org.opendaylight.yangtools.yang.binding.AugmentationHolder;
import org.opendaylight.yangtools.yang.binding.CodeHelpers;
import org.opendaylight.yangtools.yang.binding.DataObject;

/**
 * Class that builds {@link RemoveShardReplicaInputBuilder} instances. Overall design of the class is that of a
 * <a href="https://en.wikipedia.org/wiki/Fluent_interface">fluent interface</a>, where method chaining is used.
 *
 * <p>
 * In general, this class is supposed to be used like this template:
 * <pre>
 *   <code>
 *     RemoveShardReplicaInputBuilder createTarget(int fooXyzzy, int barBaz) {
 *         return new RemoveShardReplicaInputBuilderBuilder()
 *             .setFoo(new FooBuilder().setXyzzy(fooXyzzy).build())
 *             .setBar(new BarBuilder().setBaz(barBaz).build())
 *             .build();
 *     }
 *   </code>
 * </pre>
 *
 * <p>
 * This pattern is supported by the immutable nature of RemoveShardReplicaInputBuilder, as instances can be freely passed around without
 * worrying about synchronization issues.
 *
 * <p>
 * As a side note: method chaining results in:
 * <ul>
 *   <li>very efficient Java bytecode, as the method invocation result, in this case the Builder reference, is
 *       on the stack, so further method invocations just need to fill method arguments for the next method
 *       invocation, which is terminated by {@link #build()}, which is then returned from the method</li>
 *   <li>better understanding by humans, as the scope of mutable state (the builder) is kept to a minimum and is
 *       very localized</li>
 *   <li>better optimization oportunities, as the object scope is minimized in terms of invocation (rather than
 *       method) stack, making <a href="https://en.wikipedia.org/wiki/Escape_analysis">escape analysis</a> a lot
 *       easier. Given enough compiler (JIT/AOT) prowess, the cost of th builder object can be completely
 *       eliminated</li>
 * </ul>
 *
 * @see RemoveShardReplicaInputBuilder
 * @see Builder
 *
 */
public class RemoveShardReplicaInputBuilder implements Builder<RemoveShardReplicaInput> {

    private DataStoreType _dataStoreType;
    private String _memberName;
    private String _shardName;


    Map<Class<? extends Augmentation<RemoveShardReplicaInput>>, Augmentation<RemoveShardReplicaInput>> augmentation = Collections.emptyMap();

    public RemoveShardReplicaInputBuilder() {
    }

    public RemoveShardReplicaInputBuilder(RemoveShardReplicaInput base) {
        if (base instanceof AugmentationHolder) {
            @SuppressWarnings("unchecked")
            Map<Class<? extends Augmentation<RemoveShardReplicaInput>>, Augmentation<RemoveShardReplicaInput>> aug =((AugmentationHolder<RemoveShardReplicaInput>) base).augmentations();
            if (!aug.isEmpty()) {
                this.augmentation = new HashMap<>(aug);
            }
        }
        this._dataStoreType = base.getDataStoreType();
        this._memberName = base.getMemberName();
        this._shardName = base.getShardName();
    }


    public DataStoreType getDataStoreType() {
        return _dataStoreType;
    }
    
    public String getMemberName() {
        return _memberName;
    }
    
    public String getShardName() {
        return _shardName;
    }

    @SuppressWarnings({ "unchecked", "checkstyle:methodTypeParameterName"})
    public <E$$ extends Augmentation<RemoveShardReplicaInput>> E$$ augmentation(Class<E$$> augmentationType) {
        return (E$$) augmentation.get(CodeHelpers.nonNullValue(augmentationType, "augmentationType"));
    }

    
    public RemoveShardReplicaInputBuilder setDataStoreType(final DataStoreType value) {
        this._dataStoreType = value;
        return this;
    }
    
    public RemoveShardReplicaInputBuilder setMemberName(final String value) {
        this._memberName = value;
        return this;
    }
    
    public RemoveShardReplicaInputBuilder setShardName(final String value) {
        this._shardName = value;
        return this;
    }
    
    public RemoveShardReplicaInputBuilder addAugmentation(Class<? extends Augmentation<RemoveShardReplicaInput>> augmentationType, Augmentation<RemoveShardReplicaInput> augmentationValue) {
        if (augmentationValue == null) {
            return removeAugmentation(augmentationType);
        }
    
        if (!(this.augmentation instanceof HashMap)) {
            this.augmentation = new HashMap<>();
        }
    
        this.augmentation.put(augmentationType, augmentationValue);
        return this;
    }
    
    public RemoveShardReplicaInputBuilder removeAugmentation(Class<? extends Augmentation<RemoveShardReplicaInput>> augmentationType) {
        if (this.augmentation instanceof HashMap) {
            this.augmentation.remove(augmentationType);
        }
        return this;
    }

    @Override
    public RemoveShardReplicaInput build() {
        return new RemoveShardReplicaInputImpl(this);
    }

    private static final class RemoveShardReplicaInputImpl
        extends AbstractAugmentable<RemoveShardReplicaInput>
        implements RemoveShardReplicaInput {
    
        private final DataStoreType _dataStoreType;
        private final String _memberName;
        private final String _shardName;
    
        RemoveShardReplicaInputImpl(RemoveShardReplicaInputBuilder base) {
            super(base.augmentation);
            this._dataStoreType = base.getDataStoreType();
            this._memberName = base.getMemberName();
            this._shardName = base.getShardName();
        }
    
        @Override
        public DataStoreType getDataStoreType() {
            return _dataStoreType;
        }
        
        @Override
        public String getMemberName() {
            return _memberName;
        }
        
        @Override
        public String getShardName() {
            return _shardName;
        }
    
        private int hash = 0;
        private volatile boolean hashValid = false;
        
        @Override
        public int hashCode() {
            if (hashValid) {
                return hash;
            }
        
            final int prime = 31;
            int result = 1;
            result = prime * result + Objects.hashCode(_dataStoreType);
            result = prime * result + Objects.hashCode(_memberName);
            result = prime * result + Objects.hashCode(_shardName);
            result = prime * result + Objects.hashCode(augmentations());
        
            hash = result;
            hashValid = true;
            return result;
        }
    
        @Override
        public boolean equals(Object obj) {
            if (this == obj) {
                return true;
            }
            if (!(obj instanceof DataObject)) {
                return false;
            }
            if (!RemoveShardReplicaInput.class.equals(((DataObject)obj).implementedInterface())) {
                return false;
            }
            RemoveShardReplicaInput other = (RemoveShardReplicaInput)obj;
            if (!Objects.equals(_dataStoreType, other.getDataStoreType())) {
                return false;
            }
            if (!Objects.equals(_memberName, other.getMemberName())) {
                return false;
            }
            if (!Objects.equals(_shardName, other.getShardName())) {
                return false;
            }
            if (getClass() == obj.getClass()) {
                // Simple case: we are comparing against self
                RemoveShardReplicaInputImpl otherImpl = (RemoveShardReplicaInputImpl) obj;
                if (!Objects.equals(augmentations(), otherImpl.augmentations())) {
                    return false;
                }
            } else {
                // Hard case: compare our augments with presence there...
                for (Map.Entry<Class<? extends Augmentation<RemoveShardReplicaInput>>, Augmentation<RemoveShardReplicaInput>> e : augmentations().entrySet()) {
                    if (!e.getValue().equals(other.augmentation(e.getKey()))) {
                        return false;
                    }
                }
                // .. and give the other one the chance to do the same
                if (!obj.equals(this)) {
                    return false;
                }
            }
            return true;
        }
    
        @Override
        public String toString() {
            final MoreObjects.ToStringHelper helper = MoreObjects.toStringHelper("RemoveShardReplicaInput");
            CodeHelpers.appendValue(helper, "_dataStoreType", _dataStoreType);
            CodeHelpers.appendValue(helper, "_memberName", _memberName);
            CodeHelpers.appendValue(helper, "_shardName", _shardName);
            CodeHelpers.appendValue(helper, "augmentation", augmentations().values());
            return helper.toString();
        }
    }
}
